diff --git a/Jenkinsfile b/Jenkinsfile
index fe88b7a..7233ce2 100644
--- a/Jenkinsfile
+++ b/Jenkinsfile
@@ -17,7 +17,7 @@ pipeline {
/* calcolo numero versione... diverso x branch MASTER/DEVELOP */
script {
- withEnv(['NEXT_BUILD_NUMBER=193']) {
+ withEnv(['NEXT_BUILD_NUMBER=197']) {
// env.versionNumber = VersionNumber(versionNumberString : '0.8.${BUILD_DATE_FORMATTED, "yyMM"}.${BUILDS_ALL_TIME}', projectStartDate : '2019-07-01', skipFailedBuilds: true)
env.versionNumber = VersionNumber(versionNumberString : '0.8.${BUILD_DATE_FORMATTED, "yyMM"}.${BUILDS_ALL_TIME}', projectStartDate : '2019-07-01', skipFailedBuilds: true, overrideBuildsAllTime: '${NEXT_BUILD_NUMBER}')
env.versionNumberBeta = VersionNumber(versionNumberString : '0.8.${BUILD_DATE_FORMATTED, "yyMM"}-beta.${BUILDS_ALL_TIME}', projectStartDate : '2019-07-01', skipFailedBuilds: true, overrideBuildsAllTime: '${NEXT_BUILD_NUMBER}')
diff --git a/NKC_WF/Content/SheetColor.css b/NKC_WF/Content/SheetColor.css
index 9d2539f..3680df5 100644
--- a/NKC_WF/Content/SheetColor.css
+++ b/NKC_WF/Content/SheetColor.css
@@ -1,20 +1,20 @@
/* ANIMAZIONE */
.strokeThick {
- stroke-width: 5px !important;
+ stroke-width: 50px !important;
}
/* Animazione per richiamo attenzione*/
.flashStroke {
stroke: blue;
/* Safari 4.0 - 8.0 */
-webkit-animation-name: blueFlash;
- -webkit-animation-duration: 0.5s;
+ -webkit-animation-duration: 0.8s;
-webkit-animation-timing-function: linear;
-webkit-animation-delay: 0s;
-webkit-animation-iteration-count: infinite;
-webkit-animation-direction: alternate;
/* Standard syntax */
animation-name: blueFlash;
- animation-duration: 0.5s;
+ animation-duration: 0.8s;
animation-timing-function: linear;
animation-delay: 0s;
animation-iteration-count: infinite;
@@ -81,19 +81,19 @@
stroke: blue;
/* Safari 4.0 - 8.0 */
-webkit-animation-name: blueFlash;
- -webkit-animation-duration: 0.5s;
+ -webkit-animation-duration: 0.8s;
-webkit-animation-timing-function: linear;
-webkit-animation-delay: 0s;
-webkit-animation-iteration-count: infinite;
-webkit-animation-direction: alternate;
/* Standard syntax */
animation-name: blueFlash;
- animation-duration: 0.5s;
+ animation-duration: 0.8s;
animation-timing-function: linear;
animation-delay: 0s;
animation-iteration-count: infinite;
animation-direction: alternate;
- stroke-width: 5px !important;
+ stroke-width: 50px !important;
}
#BLK-BIN {
fill: #28a745;
diff --git a/NKC_WF/Content/SheetColor.less b/NKC_WF/Content/SheetColor.less
index b4330c0..2437d38 100644
--- a/NKC_WF/Content/SheetColor.less
+++ b/NKC_WF/Content/SheetColor.less
@@ -1,5 +1,5 @@
/* ANIMAZIONE */
-@borderThick: 5px;
+@borderThick: 50px;
.strokeThick {
stroke-width: @borderThick !important;
@@ -9,14 +9,14 @@
stroke: blue;
/* Safari 4.0 - 8.0 */
-webkit-animation-name: blueFlash;
- -webkit-animation-duration: 0.5s;
+ -webkit-animation-duration: 0.8s;
-webkit-animation-timing-function: linear;
-webkit-animation-delay: 0s;
-webkit-animation-iteration-count: infinite;
-webkit-animation-direction: alternate;
/* Standard syntax */
animation-name: blueFlash;
- animation-duration: 0.5s;
+ animation-duration: 0.8s;
animation-timing-function: linear;
animation-delay: 0s;
animation-iteration-count: infinite;
diff --git a/NKC_WF/Content/SheetColor.min.css b/NKC_WF/Content/SheetColor.min.css
index f6b23d9..840c089 100644
--- a/NKC_WF/Content/SheetColor.min.css
+++ b/NKC_WF/Content/SheetColor.min.css
@@ -1 +1 @@
-.strokeThick{stroke-width:5px !important;}.flashStroke{stroke:blue;-webkit-animation-name:blueFlash;-webkit-animation-duration:.5s;-webkit-animation-timing-function:linear;-webkit-animation-delay:0s;-webkit-animation-iteration-count:infinite;-webkit-animation-direction:alternate;animation-name:blueFlash;animation-duration:.5s;animation-timing-function:linear;animation-delay:0s;animation-iteration-count:infinite;animation-direction:alternate;}@-webkit-keyframes blueFlash{0%{stroke:#c4dbff;}25%{stroke:#9dc4ff;}50%{stroke:#5ca5ff;}75%{stroke:#1b82ff;}100%{stroke:#005ccc;}}.SFONDO{fill:#dedede;}.GRIGIO{fill:#acacac;}.VERDE{fill:#28a745;}.BLU{fill:#007bff;}.ARANCIO{fill:orange;}.GIALLO{fill:yellow;}.PURPLE{fill:purple;}.TESTO{fill:white;}#BLK-BCK{fill:#dedede;}#BLK-CUT{fill:#acacac;}#BLK-SEL{fill:orange;stroke:blue;-webkit-animation-name:blueFlash;-webkit-animation-duration:.5s;-webkit-animation-timing-function:linear;-webkit-animation-delay:0s;-webkit-animation-iteration-count:infinite;-webkit-animation-direction:alternate;animation-name:blueFlash;animation-duration:.5s;animation-timing-function:linear;animation-delay:0s;animation-iteration-count:infinite;animation-direction:alternate;stroke-width:5px !important;}#BLK-BIN{fill:#28a745;}#BLK-CART{fill:#007bff;}#BLK-SEC-OP{fill:purple;}
\ No newline at end of file
+.strokeThick{stroke-width:50px !important;}.flashStroke{stroke:blue;-webkit-animation-name:blueFlash;-webkit-animation-duration:.8s;-webkit-animation-timing-function:linear;-webkit-animation-delay:0s;-webkit-animation-iteration-count:infinite;-webkit-animation-direction:alternate;animation-name:blueFlash;animation-duration:.8s;animation-timing-function:linear;animation-delay:0s;animation-iteration-count:infinite;animation-direction:alternate;}@-webkit-keyframes blueFlash{0%{stroke:#c4dbff;}25%{stroke:#9dc4ff;}50%{stroke:#5ca5ff;}75%{stroke:#1b82ff;}100%{stroke:#005ccc;}}.SFONDO{fill:#dedede;}.GRIGIO{fill:#acacac;}.VERDE{fill:#28a745;}.BLU{fill:#007bff;}.ARANCIO{fill:orange;}.GIALLO{fill:yellow;}.PURPLE{fill:purple;}.TESTO{fill:white;}#BLK-BCK{fill:#dedede;}#BLK-CUT{fill:#acacac;}#BLK-SEL{fill:orange;stroke:blue;-webkit-animation-name:blueFlash;-webkit-animation-duration:.8s;-webkit-animation-timing-function:linear;-webkit-animation-delay:0s;-webkit-animation-iteration-count:infinite;-webkit-animation-direction:alternate;animation-name:blueFlash;animation-duration:.8s;animation-timing-function:linear;animation-delay:0s;animation-iteration-count:infinite;animation-direction:alternate;stroke-width:50px !important;}#BLK-BIN{fill:#28a745;}#BLK-CART{fill:#007bff;}#BLK-SEC-OP{fill:purple;}
\ No newline at end of file
diff --git a/NKC_WF/Images/Batch/B20190916.0/ST0000001/SH0000002.svg b/NKC_WF/Images/Batch/B20190916.0/ST0000001/SH0000002.svg
deleted file mode 100644
index 1f44c04..0000000
--- a/NKC_WF/Images/Batch/B20190916.0/ST0000001/SH0000002.svg
+++ /dev/null
@@ -1,25 +0,0 @@
-
-
-
-
- IT000001
-
-
-
-
-
- IT000002
-
-
- IT000003
-
-
-
-
-
-
-
-
-
-
-
\ No newline at end of file
diff --git a/NKC_WF/Images/test_no.svg b/NKC_WF/Images/NoData.svg
similarity index 100%
rename from NKC_WF/Images/test_no.svg
rename to NKC_WF/Images/NoData.svg
diff --git a/NKC_WF/Images/Test11.svg b/NKC_WF/Images/Test11.svg
deleted file mode 100644
index 6a88b42..0000000
--- a/NKC_WF/Images/Test11.svg
+++ /dev/null
@@ -1,25 +0,0 @@
-
-
-
-
- Part 1
-
-
-
-
-
- Part 2
-
-
- Part 3
-
-
-
-
-
-
-
-
-
-
-
\ No newline at end of file
diff --git a/NKC_WF/Images/test.svg b/NKC_WF/Images/test.svg
index 1f44c04..fb0c2a2 100644
--- a/NKC_WF/Images/test.svg
+++ b/NKC_WF/Images/test.svg
@@ -1,25 +1,84 @@
-
-
-
- IT000001
-
-
-
-
-
- IT000002
-
-
- IT000003
-
-
-
-
-
-
-
-
-
-
-
\ No newline at end of file
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 1
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 1
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 1
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ 2
+
+
+
diff --git a/NKC_WF/Images/Batch/B20190916.0/ST0000001/SH0000001.svg b/NKC_WF/Images/test_a.svg
similarity index 100%
rename from NKC_WF/Images/Batch/B20190916.0/ST0000001/SH0000001.svg
rename to NKC_WF/Images/test_a.svg
diff --git a/NKC_WF/Images/test_b.svg b/NKC_WF/Images/test_b.svg
deleted file mode 100644
index ed10a30..0000000
--- a/NKC_WF/Images/test_b.svg
+++ /dev/null
@@ -1,45 +0,0 @@
-
-
-
-
-
-
- image/svg+xml
-
-
-
-
-
-
-
-
-
-
-
-
-
-
diff --git a/NKC_WF/Images/test_bis.svg b/NKC_WF/Images/test_bis.svg
deleted file mode 100644
index 2508d79..0000000
--- a/NKC_WF/Images/test_bis.svg
+++ /dev/null
@@ -1,111 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
diff --git a/NKC_WF/Images/test_quadrato.svg b/NKC_WF/Images/test_quadrato.svg
deleted file mode 100644
index 047d55b..0000000
--- a/NKC_WF/Images/test_quadrato.svg
+++ /dev/null
@@ -1,658 +0,0 @@
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
diff --git a/NKC_WF/NKC_WF.csproj b/NKC_WF/NKC_WF.csproj
index 6b4a835..634b45d 100644
--- a/NKC_WF/NKC_WF.csproj
+++ b/NKC_WF/NKC_WF.csproj
@@ -233,8 +233,15 @@
+
+ SheetColor.less
+
+
+ SheetColor.css
+
+
@@ -256,23 +263,13 @@
fonts.css
-
- SheetColor.less
-
-
- SheetColor.css
-
-
-
-
-
-
-
+
+
@@ -302,6 +299,10 @@
+
+
+
+
@@ -312,6 +313,7 @@
+
@@ -755,6 +757,34 @@
cmp_ML_ShDet.ascx
+
+ cmp_MU_carts.ascx
+ ASPXCodeBehind
+
+
+ cmp_MU_carts.ascx
+
+
+ cmp_MU_stats.ascx
+ ASPXCodeBehind
+
+
+ cmp_MU_stats.ascx
+
+
+ cmp_MU_bins.ascx
+ ASPXCodeBehind
+
+
+ cmp_MU_bins.ascx
+
+
+ cmp_MU_suggestions.ascx
+ ASPXCodeBehind
+
+
+ cmp_MU_suggestions.ascx
+
cmp_numRow.ascx
ASPXCodeBehind
@@ -825,6 +855,13 @@
cmp_stackNextloading.ascx
+
+ cmp_MU_svgViewer.ascx
+ ASPXCodeBehind
+
+
+ cmp_MU_svgViewer.ascx
+
cmp_taktList.ascx
ASPXCodeBehind
diff --git a/NKC_WF/Web.config b/NKC_WF/Web.config
index c411594..afd11a6 100644
--- a/NKC_WF/Web.config
+++ b/NKC_WF/Web.config
@@ -63,6 +63,8 @@
+
+
diff --git a/NKC_WF/WebUserControls/cmp_MU_bins.ascx b/NKC_WF/WebUserControls/cmp_MU_bins.ascx
new file mode 100644
index 0000000..e8553a2
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_bins.ascx
@@ -0,0 +1,92 @@
+<%@ Control Language="C#" AutoEventWireup="true" CodeBehind="cmp_MU_bins.ascx.cs" Inherits="NKC_WF.WebUserControls.cmp_MU_bins" %>
+
+
+
+
+
+
+
+
+
+ Cod
+ D/T
+ %
+
+
+
+
+ BIN00008
+ 50/50
+ 100%
+
+
+ BIN00009
+ 50/50
+ 100%
+
+
+ BIN00010
+ 50/50
+ 100%
+
+
+ BIN00011
+ 50/50
+ 100%
+
+
+ BIN00012
+ 12/50
+ 24%
+
+
+ BIN00013
+ 10/50
+ 20%
+
+
+ BIN00014
+ 1/50
+ 2%
+
+
+ BIN00015
+ 0/50
+ 0%
+
+
+ BIN00016
+ 0/50
+ 0%
+
+
+ BIN00017
+ 0/50
+ 0%
+
+
+ BIN00018
+ 0/50
+ 0%
+
+
+ BIN00019
+ 0/50
+ 0%
+
+
+ BIN00020
+ 0/50
+ 0%
+
+
+ BIN00021
+ 0/50
+ 0%
+
+
+
+
+
+
+
diff --git a/NKC_WF/WebUserControls/cmp_MU_bins.ascx.cs b/NKC_WF/WebUserControls/cmp_MU_bins.ascx.cs
new file mode 100644
index 0000000..c1caa0c
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_bins.ascx.cs
@@ -0,0 +1,17 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Web;
+using System.Web.UI;
+using System.Web.UI.WebControls;
+
+namespace NKC_WF.WebUserControls
+{
+ public partial class cmp_MU_bins : System.Web.UI.UserControl
+ {
+ protected void Page_Load(object sender, EventArgs e)
+ {
+
+ }
+ }
+}
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_MU_bins.ascx.designer.cs b/NKC_WF/WebUserControls/cmp_MU_bins.ascx.designer.cs
new file mode 100644
index 0000000..0c0dfba
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_bins.ascx.designer.cs
@@ -0,0 +1,17 @@
+//------------------------------------------------------------------------------
+//
+// Codice generato da uno strumento.
+//
+// Le modifiche a questo file possono causare un comportamento non corretto e verranno perse se
+// il codice viene rigenerato.
+//
+//------------------------------------------------------------------------------
+
+namespace NKC_WF.WebUserControls
+{
+
+
+ public partial class cmp_MU_bins
+ {
+ }
+}
diff --git a/NKC_WF/WebUserControls/cmp_MU_carts.ascx b/NKC_WF/WebUserControls/cmp_MU_carts.ascx
new file mode 100644
index 0000000..c5a955d
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_carts.ascx
@@ -0,0 +1,92 @@
+<%@ Control Language="C#" AutoEventWireup="true" CodeBehind="cmp_MU_carts.ascx.cs" Inherits="NKC_WF.WebUserControls.cmp_MU_carts" %>
+
+
+
+
+
+
+
+
+
+ Cod
+ D/T
+ %
+
+
+
+
+ CR00007
+ 50/50
+ 100%
+
+
+ CR00008
+ 50/50
+ 100%
+
+
+ CR00009
+ 50/50
+ 100%
+
+
+ CR00010
+ 50/50
+ 100%
+
+
+ CR00011
+ 50/50
+ 100%
+
+
+ CR00012
+ 12/50
+ 24%
+
+
+ CR00013
+ 10/50
+ 20%
+
+
+ CR00014
+ 0/50
+ 0%
+
+
+ CR00015
+ 0/50
+ 0%
+
+
+ CR00016
+ 0/50
+ 0%
+
+
+ CR00017
+ 0/50
+ 0%
+
+
+ CR00018
+ 0/50
+ 0%
+
+
+ CR00019
+ 0/50
+ 0%
+
+
+ CR00020
+ 0/50
+ 0%
+
+
+
+
+
+
+
diff --git a/NKC_WF/WebUserControls/cmp_MU_carts.ascx.cs b/NKC_WF/WebUserControls/cmp_MU_carts.ascx.cs
new file mode 100644
index 0000000..99da0a5
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_carts.ascx.cs
@@ -0,0 +1,17 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Web;
+using System.Web.UI;
+using System.Web.UI.WebControls;
+
+namespace NKC_WF.WebUserControls
+{
+ public partial class cmp_MU_carts : System.Web.UI.UserControl
+ {
+ protected void Page_Load(object sender, EventArgs e)
+ {
+
+ }
+ }
+}
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_MU_carts.ascx.designer.cs b/NKC_WF/WebUserControls/cmp_MU_carts.ascx.designer.cs
new file mode 100644
index 0000000..904580f
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_carts.ascx.designer.cs
@@ -0,0 +1,17 @@
+//------------------------------------------------------------------------------
+//
+// Codice generato da uno strumento.
+//
+// Le modifiche a questo file possono causare un comportamento non corretto e verranno perse se
+// il codice viene rigenerato.
+//
+//------------------------------------------------------------------------------
+
+namespace NKC_WF.WebUserControls
+{
+
+
+ public partial class cmp_MU_carts
+ {
+ }
+}
diff --git a/NKC_WF/WebUserControls/cmp_MU_stats.ascx b/NKC_WF/WebUserControls/cmp_MU_stats.ascx
new file mode 100644
index 0000000..4ece5a3
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_stats.ascx
@@ -0,0 +1,124 @@
+<%@ Control Language="C#" AutoEventWireup="true" CodeBehind="cmp_MU_stats.ascx.cs" Inherits="NKC_WF.WebUserControls.cmp_MU_stats" %>
+
+
+
+
+
+
+
+
+
+
+ WAIT
+ WIP
+ DONE
+
+
+
+
+ 12
+ 3
+ 5
+
+
+
+
+
+
+
+
+
+
+
+
+
+ DONE
+ TOT
+ RATIO
+
+
+
+
+ 5
+ 25
+ 20%
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ DONE
+ TOT
+ RATIO
+
+
+
+
+ 3
+ 12
+ 25%
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ DONE
+ TOT
+ RATIO
+
+
+
+
+ 2
+ 5
+ 40%
+
+
+
+
+
+
+
+
+
+
+
+
+
+ WAIT
+ WIP
+ DONE
+
+
+
+
+ 24
+ 2
+ 6
+
+
+
+
+
+
+
diff --git a/NKC_WF/WebUserControls/cmp_MU_stats.ascx.cs b/NKC_WF/WebUserControls/cmp_MU_stats.ascx.cs
new file mode 100644
index 0000000..c6cf7bf
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_stats.ascx.cs
@@ -0,0 +1,17 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Web;
+using System.Web.UI;
+using System.Web.UI.WebControls;
+
+namespace NKC_WF.WebUserControls
+{
+ public partial class cmp_MU_stats : System.Web.UI.UserControl
+ {
+ protected void Page_Load(object sender, EventArgs e)
+ {
+
+ }
+ }
+}
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_MU_stats.ascx.designer.cs b/NKC_WF/WebUserControls/cmp_MU_stats.ascx.designer.cs
new file mode 100644
index 0000000..93aede4
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_stats.ascx.designer.cs
@@ -0,0 +1,17 @@
+//------------------------------------------------------------------------------
+//
+// Codice generato da uno strumento.
+//
+// Le modifiche a questo file possono causare un comportamento non corretto e verranno perse se
+// il codice viene rigenerato.
+//
+//------------------------------------------------------------------------------
+
+namespace NKC_WF.WebUserControls
+{
+
+
+ public partial class cmp_MU_stats
+ {
+ }
+}
diff --git a/NKC_WF/WebUserControls/cmp_MU_suggestions.ascx b/NKC_WF/WebUserControls/cmp_MU_suggestions.ascx
new file mode 100644
index 0000000..d250e45
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_suggestions.ascx
@@ -0,0 +1,64 @@
+<%@ Control Language="C#" AutoEventWireup="true" CodeBehind="cmp_MU_suggestions.ascx.cs" Inherits="NKC_WF.WebUserControls.cmp_MU_suggestions" %>
+
+
+
+
+
+
+
+
+ BIN00010
+
+
+
+
+
+ IT000002
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+ IT000001
+
+
+
+
+
+ CR00007
+
+
+
+
+
+
+
+
+
+
+
+ IT000003
+
+
+
+
+
+ CR00012
+
+
+
+
+
+
diff --git a/NKC_WF/WebUserControls/cmp_MU_suggestions.ascx.cs b/NKC_WF/WebUserControls/cmp_MU_suggestions.ascx.cs
new file mode 100644
index 0000000..cc34ba7
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_suggestions.ascx.cs
@@ -0,0 +1,17 @@
+using System;
+using System.Collections.Generic;
+using System.Linq;
+using System.Web;
+using System.Web.UI;
+using System.Web.UI.WebControls;
+
+namespace NKC_WF.WebUserControls
+{
+ public partial class cmp_MU_suggestions : System.Web.UI.UserControl
+ {
+ protected void Page_Load(object sender, EventArgs e)
+ {
+
+ }
+ }
+}
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_MU_suggestions.ascx.designer.cs b/NKC_WF/WebUserControls/cmp_MU_suggestions.ascx.designer.cs
new file mode 100644
index 0000000..827bf22
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_suggestions.ascx.designer.cs
@@ -0,0 +1,17 @@
+//------------------------------------------------------------------------------
+//
+// Codice generato da uno strumento.
+//
+// Le modifiche a questo file possono causare un comportamento non corretto e verranno perse se
+// il codice viene rigenerato.
+//
+//------------------------------------------------------------------------------
+
+namespace NKC_WF.WebUserControls
+{
+
+
+ public partial class cmp_MU_suggestions
+ {
+ }
+}
diff --git a/NKC_WF/WebUserControls/cmp_MU_svgViewer.ascx b/NKC_WF/WebUserControls/cmp_MU_svgViewer.ascx
new file mode 100644
index 0000000..6696e5c
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_svgViewer.ascx
@@ -0,0 +1,23 @@
+<%@ Control Language="C#" AutoEventWireup="true" CodeBehind="cmp_MU_svgViewer.ascx.cs" Inherits="NKC_WF.WebUserControls.cmp_MU_svgViewer" %>
+
+
+
+
+
+
+
+
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_MU_svgViewer.ascx.cs b/NKC_WF/WebUserControls/cmp_MU_svgViewer.ascx.cs
new file mode 100644
index 0000000..b0b2b7b
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_svgViewer.ascx.cs
@@ -0,0 +1,69 @@
+using AppData;
+using SteamWare;
+using System;
+using System.Collections.Generic;
+using System.IO;
+using System.Linq;
+using System.Web;
+using System.Web.UI;
+using System.Web.UI.WebControls;
+
+namespace NKC_WF.WebUserControls
+{
+ public partial class cmp_MU_svgViewer : System.Web.UI.UserControl
+ {
+ ///
+ /// Batch corrente...
+ ///
+ public int BatchId
+ {
+ set
+ {
+ hfBatchID.Value = value.ToString();
+ doUpdate();
+ }
+ get
+ {
+ int answ = 0;
+ int.TryParse(hfBatchID.Value, out answ);
+ return answ;
+ }
+ }
+ public void doUpdate()
+ {
+ // recupero ID del foglio corrente
+ int sheetId = 0;
+ string answ = "";
+ string filename = "";
+ try
+ {
+ // FORSE 5/5?!?
+ var sheetList = DataLayer.man.taSHL.getByMLStatus(BatchId, 3, 5);
+ if (sheetList.Count > 0)
+ {
+ sheetId = sheetList[0].SheetID;
+ // lo leggo da file
+ string baseOrig = memLayer.ML.CRS("drawBaseBath").ToLower();
+ string baseCurr = memLayer.ML.CRS("srvDrawBaseBath").ToLower();
+ filename = sheetList[0].DrawFilePath.ToLower().Replace(baseOrig, baseCurr);
+ // NON DOVREBEB SERVIRE MAP se è già share di rete... anche se è su MEDESIMA macchina
+ //filename = Server.MapPath(filename);
+ answ = File.ReadAllText(filename);
+ }
+ }
+ catch
+ { }
+ if (answ == "")
+ {
+ // leggo SVG DI DEFAULT che indica NON PRESENTE...
+ filename = Server.MapPath("~/Images/NoData.svg");
+ answ = File.ReadAllText(filename);
+ }
+ // update componente svg!
+ svgTable.InnerHtml = answ;
+ }
+ protected void Page_Load(object sender, EventArgs e)
+ {
+ }
+ }
+}
\ No newline at end of file
diff --git a/NKC_WF/WebUserControls/cmp_MU_svgViewer.ascx.designer.cs b/NKC_WF/WebUserControls/cmp_MU_svgViewer.ascx.designer.cs
new file mode 100644
index 0000000..131f885
--- /dev/null
+++ b/NKC_WF/WebUserControls/cmp_MU_svgViewer.ascx.designer.cs
@@ -0,0 +1,35 @@
+//------------------------------------------------------------------------------
+//
+// Codice generato da uno strumento.
+//
+// Le modifiche a questo file possono causare un comportamento non corretto e verranno perse se
+// il codice viene rigenerato.
+//
+//------------------------------------------------------------------------------
+
+namespace NKC_WF.WebUserControls
+{
+
+
+ public partial class cmp_MU_svgViewer
+ {
+
+ ///
+ /// Controllo svgTable.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.HtmlControls.HtmlGenericControl svgTable;
+
+ ///
+ /// Controllo hfBatchID.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.WebControls.HiddenField hfBatchID;
+ }
+}
diff --git a/NKC_WF/WebUserControls/cmp_batchDetail.ascx.cs b/NKC_WF/WebUserControls/cmp_batchDetail.ascx.cs
index 62512d3..b5e9dc6 100644
--- a/NKC_WF/WebUserControls/cmp_batchDetail.ascx.cs
+++ b/NKC_WF/WebUserControls/cmp_batchDetail.ascx.cs
@@ -2,6 +2,7 @@
using NKC_SDK;
using SteamWare;
using System;
+using System.Collections.Generic;
using System.Text;
namespace NKC_WF.WebUserControls
@@ -29,18 +30,93 @@ namespace NKC_WF.WebUserControls
sb.AppendLine("DEBUG INFO:");
if (estimAnsw != null)
{
+ // elenchi x ricerca duplicati
+ List partListEstim = new List();
+ List partListEstimDupl = new List();
try
{
- sb.AppendLine($"ESTIM: EnvNum: {estimAnsw.EnvNum} | Worktime: {estimAnsw.EstimatedWorktime / 60:N2} min | Processing Runtime {estimAnsw.ProcessingRuntime / 60:N2} min | Parts #: {estimAnsw.PartList.Count}");
+ foreach (var part in estimAnsw.PartList)
+ {
+ if (partListEstim.Contains(part.PartId))
+ {
+ partListEstimDupl.Add(part.PartId);
+ }
+ else
+ {
+ partListEstim.Add(part.PartId);
+ }
+ }
+ }
+ catch
+ { }
+ try
+ {
+ sb.AppendLine($"ESTIM: EnvNum: {estimAnsw.EnvNum} | Worktime: {estimAnsw.EstimatedWorktime / 60:N2} min | Processing Runtime {estimAnsw.ProcessingRuntime / 60:N2} min | Parts #: {estimAnsw.PartList.Count} | Distinct Part # {partListEstim.Count}");
+ // se ho duplicati indico:
+ if (partListEstimDupl.Count > 0)
+ {
+ sb.AppendLine("---------------------");
+ sb.AppendLine($"ESTIM: FOUND {partListEstimDupl.Count} duplicate:");
+ foreach (var partId in partListEstimDupl)
+ {
+ sb.AppendLine($"{partId}");
+ }
+ sb.AppendLine("---------------------");
+ }
}
catch
{ }
}
if (nestAnsw != null)
{
+ // elenchi x ricerca duplicati
+ List partListNest = new List();
+ List partListNestDupl = new List();
try
{
- sb.AppendLine($"NEST: EnvNum: {nestAnsw.EnvNum} | Worktime: {nestAnsw.EstimatedWorktime / 60:N2} min | Processing Runtime {nestAnsw.ProcessingRuntime / 60:N2} min | Bunks #: {nestAnsw.BunkList.Count} | Carts #: {nestAnsw.CartList.Count}");
+ foreach (var bunk in nestAnsw.BunkList)
+ {
+ foreach (var sheet in bunk.SheetList)
+ {
+ foreach (var part in sheet.PartList)
+ {
+ if (partListNest.Contains(part.PartId))
+ {
+ partListNestDupl.Add(part.PartId);
+ }
+ else
+ {
+ partListNest.Add(part.PartId);
+ }
+ }
+ }
+ }
+ }
+ catch
+ { }
+ //il tot delle part è in bunk > Sheet > part
+ int totPartNum = 0;
+ foreach (var bunk in nestAnsw.BunkList)
+ {
+ foreach (var sheet in bunk.SheetList)
+ {
+ totPartNum += sheet.PartList.Count;
+ }
+ }
+ try
+ {
+ sb.AppendLine($"NEST: EnvNum: {nestAnsw.EnvNum} | Worktime: {nestAnsw.EstimatedWorktime / 60:N2} min | Processing Runtime {nestAnsw.ProcessingRuntime / 60:N2} min | Bunks #: {nestAnsw.BunkList.Count} | Carts #: {nestAnsw.CartList.Count} | Parts #: {totPartNum}");
+ // se ho duplicati indico:
+ if (partListNestDupl.Count > 0)
+ {
+ sb.AppendLine("---------------------");
+ sb.AppendLine($"ESTIM: FOUND {partListNestDupl.Count} duplicate:");
+ foreach (var partId in partListNestDupl)
+ {
+ sb.AppendLine($"{partId}");
+ }
+ sb.AppendLine("---------------------");
+ }
}
catch
{ }
diff --git a/NKC_WF/site/MachineUnload.aspx b/NKC_WF/site/MachineUnload.aspx
index 1eabd98..e6f488f 100644
--- a/NKC_WF/site/MachineUnload.aspx
+++ b/NKC_WF/site/MachineUnload.aspx
@@ -1,476 +1,37 @@
<%@ Page Title="" Language="C#" MasterPageFile="~/Site.Master" AutoEventWireup="true" CodeBehind="MachineUnload.aspx.cs" Inherits="NKC_WF.MachineUnload" %>
-
- <%--
-
-
-
-
- --%>
- <%--
-
-
-
-
- --%>
-
-
-
-
+<%@ Register Src="~/WebUserControls/cmp_MU_svgViewer.ascx" TagPrefix="uc1" TagName="cmp_MU_svgViewer" %>
+<%@ Register Src="~/WebUserControls/cmp_MU_stats.ascx" TagPrefix="uc1" TagName="cmp_MU_stats" %>
+<%@ Register Src="~/WebUserControls/cmp_MU_suggestions.ascx" TagPrefix="uc1" TagName="cmp_MU_suggestions" %>
+<%@ Register Src="~/WebUserControls/cmp_MU_bins.ascx" TagPrefix="uc1" TagName="cmp_MU_bins" %>
+<%@ Register Src="~/WebUserControls/cmp_MU_carts.ascx" TagPrefix="uc1" TagName="cmp_MU_carts" %>
+
+
+
+
+
+
+
-
-
-
-
-
-
-
-
- WAIT
- WIP
- DONE
-
-
-
-
- 12
- 3
- 5
-
-
-
-
-
-
-
-
-
-
-
-
-
- DONE
- TOT
- RATIO
-
-
-
-
- 5
- 25
- 20%
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- DONE
- TOT
- RATIO
-
-
-
-
- 3
- 12
- 25%
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- DONE
- TOT
- RATIO
-
-
-
-
- 2
- 5
- 40%
-
-
-
-
-
-
-
-
-
-
-
-
-
- WAIT
- WIP
- DONE
-
-
-
-
- 24
- 2
- 6
-
-
-
-
-
-
-
+
-
-
-
-
-
-
-
-
- Cod
- D/T
- %
-
-
-
-
- BIN00007
- 50/50
- 100%
-
-
- BIN00008
- 50/50
- 100%
-
-
- BIN00009
- 50/50
- 100%
-
-
- BIN00010
- 50/50
- 100%
-
-
- BIN00011
- 50/50
- 100%
-
-
- BIN00012
- 12/50
- 24%
-
-
- BIN00013
- 10/50
- 20%
-
-
- BIN00014
- 1/50
- 2%
-
-
- BIN00015
- 0/50
- 0%
-
-
- BIN00016
- 0/50
- 0%
-
-
- BIN00017
- 0/50
- 0%
-
-
- BIN00018
- 0/50
- 0%
-
-
- BIN00019
- 0/50
- 0%
-
-
- BIN00020
- 0/50
- 0%
-
-
- BIN00021
- 0/50
- 0%
-
-
- BIN00022
- 0/50
- 0%
-
-
- BIN00023
- 0/50
- 0%
-
-
- BIN00024
- 0/50
- 0%
-
-
- BIN00025
- 0/50
- 0%
-
-
- BIN00026
- 0/50
- 0%
-
-
-
-
-
-
-
+
-
-
+
-
-
-
-
-
-
-
-
- Cod
- D/T
- %
-
-
-
-
- CR00006
- 50/50
- 100%
-
-
- CR00007
- 50/50
- 100%
-
-
- CR00008
- 50/50
- 100%
-
-
- CR00009
- 50/50
- 100%
-
-
- CR00010
- 50/50
- 100%
-
-
- CR00011
- 50/50
- 100%
-
-
- CR00012
- 12/50
- 24%
-
-
- CR00013
- 10/50
- 20%
-
-
- CR00014
- 0/50
- 0%
-
-
- CR00015
- 0/50
- 0%
-
-
- CR00016
- 0/50
- 0%
-
-
- CR00017
- 0/50
- 0%
-
-
- CR00018
- 0/50
- 0%
-
-
- CR00019
- 0/50
- 0%
-
-
- CR00020
- 0/50
- 0%
-
-
- CR00021
- 0/50
- 0%
-
-
- CR00022
- 0/50
- 0%
-
-
- CR00023
- 0/50
- 0%
-
-
- CR00024
- 0/50
- 0%
-
-
- CR00025
- 0/50
- 0%
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- BIN00010
-
-
-
-
-
- IT000002
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- IT000001
-
-
-
-
-
- CR00007
-
-
-
-
-
-
-
-
-
-
-
- IT000003
-
-
-
-
-
- CR00012
-
-
-
-
+
+
diff --git a/NKC_WF/site/MachineUnload.aspx.cs b/NKC_WF/site/MachineUnload.aspx.cs
index 219215e..a097a87 100644
--- a/NKC_WF/site/MachineUnload.aspx.cs
+++ b/NKC_WF/site/MachineUnload.aspx.cs
@@ -7,14 +7,36 @@ namespace NKC_WF
{
protected void Page_Load(object sender, EventArgs e)
{
- string filename = Server.MapPath("~/Images/test.svg");
- string answ = File.ReadAllText(filename);
- svgTable.InnerHtml = answ;
+ if (!Page.IsPostBack)
+ {
+ doUpdate();
+ }
}
-
- protected void timReloadCss_Tick(object sender, EventArgs e)
+ ///
+ /// Batch corrente...
+ ///
+ public int BatchId
{
-
+ set
+ {
+ hfBatchID.Value = value.ToString();
+ }
+ get
+ {
+ int answ = 0;
+ int.TryParse(hfBatchID.Value, out answ);
+ return answ;
+ }
+ }
+ ///
+ /// Aggiorna componente principale e child components
+ ///
+ private void doUpdate()
+ {
+ //!!!FIXME!!! fare calcolo del VERO batch corrente...
+ BatchId = 242; // fixed x test!
+ // aggiorno child
+ cmp_MU_svgViewer.BatchId = BatchId;
}
}
}
\ No newline at end of file
diff --git a/NKC_WF/site/MachineUnload.aspx.designer.cs b/NKC_WF/site/MachineUnload.aspx.designer.cs
index b6f5512..14b0e32 100644
--- a/NKC_WF/site/MachineUnload.aspx.designer.cs
+++ b/NKC_WF/site/MachineUnload.aspx.designer.cs
@@ -7,27 +7,74 @@
//
//------------------------------------------------------------------------------
-namespace NKC_WF {
-
-
- public partial class MachineUnload {
-
- ///
- /// Controllo upnlDrawings.
- ///
- ///
- /// Campo generato automaticamente.
- /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
- ///
- protected global::System.Web.UI.UpdatePanel upnlDrawings;
-
- ///
- /// Controllo svgTable.
- ///
- ///
- /// Campo generato automaticamente.
- /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
- ///
- protected global::System.Web.UI.HtmlControls.HtmlGenericControl svgTable;
- }
+namespace NKC_WF
+{
+
+
+ public partial class MachineUnload
+ {
+
+ ///
+ /// Controllo hfBatchID.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.WebControls.HiddenField hfBatchID;
+
+ ///
+ /// Controllo upnlDrawings.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::System.Web.UI.UpdatePanel upnlDrawings;
+
+ ///
+ /// Controllo cmp_MU_stats.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_MU_stats cmp_MU_stats;
+
+ ///
+ /// Controllo cmp_MU_bins.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_MU_bins cmp_MU_bins;
+
+ ///
+ /// Controllo cmp_MU_svgViewer.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_MU_svgViewer cmp_MU_svgViewer;
+
+ ///
+ /// Controllo cmp_MU_carts.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_MU_carts cmp_MU_carts;
+
+ ///
+ /// Controllo cmp_MU_suggestions.
+ ///
+ ///
+ /// Campo generato automaticamente.
+ /// Per la modifica, spostare la dichiarazione di campo dal file di progettazione al file code-behind.
+ ///
+ protected global::NKC_WF.WebUserControls.cmp_MU_suggestions cmp_MU_suggestions;
+ }
}